@@ -38,10 +38,10 @@ def pull(toolVersionId):
     template['id'] = toolEntity['id']
     auth = common.get(url=common.get_cloud_base_url() + '/tool/pass')
     client = docker.from_env()
-    for line in client.images.pull(repository=common.get_docker_registry() + '/' + pullToolEntity['path'],
+    print("pull in, please wait")
+    client.images.pull(repository=common.get_docker_registry() + '/' + pullToolEntity['path'],
                        tag="latest",
-                       auth_config={'username': auth['account'], 'password': auth['password']}):
-        print(line)
+                       auth_config={'username': auth['account'], 'password': auth['password']})
 
     image = client.images.get(common.get_docker_registry() + '/' + pullToolEntity['path'] + ':latest')
     image.tag(repository=toolEntity['id'], tag=str(pullToolEntity['version']))
