@@ -115,6 +115,14 @@ def checkToolConfig(toolConfig):
     if toolConfig['cmd'] != '':
         toolVersionCmdParamList = analysis(cmd=toolConfig['cmd'])
 
+    have_in_dir = False
+    have_out_dir = False
+    for cmdParam in toolVersionCmdParamList:
+        if cmdParam['type'] == 4:
+            have_in_dir = True
+        if cmdParam['type'] == 5:
+            have_out_dir = True
+
     toolInputFileList = toolConfig['inputs']
 
     inLabelSet = set()
@@ -127,6 +135,9 @@ def checkToolConfig(toolConfig):
         if inputFile['key'] != '':
             inFileKeyList.add(inputFile['key'])
             inFileKeyLength = inFileKeyLength + 1
+        else:
+            if not have_in_dir:
+                myLogger.error_logger('CMD does not match the parameter')
 
     outLabelSet = set()
     outFileKeyList = set()
@@ -148,6 +159,9 @@ def checkToolConfig(toolConfig):
                 myLogger.error_logger('Output command line arguments are not available *')
             outFileKeyList.add(outFile['key'])
             outFileKeyLength = outFileKeyLength + 1
+        else:
+            if not have_out_dir:
+                myLogger.error_logger('CMD does not match the parameter')
 
         if outFile['key'] == '' and '*' in outFile['name']:
             if outFile['name'].startswith('*.'):
@@ -174,11 +188,18 @@ def checkToolConfig(toolConfig):
         if toolVersionCmdParam['type'] == 2:
             toolVersionParamsInFileKeySet.add(toolVersionCmdParam['paramKey'])
 
+    if len(toolVersionParamsInFileKeySet) == 0 and inFileKeyLength > 0:
+        myLogger.error_logger('input error')
+
+
     toolVersionParamsOutFileKeySet = set()
     for toolVersionCmdParam in toolVersionCmdParamList:
         if toolVersionCmdParam['type'] == 3:
             toolVersionParamsOutFileKeySet.add(toolVersionCmdParam['paramKey'])
 
+    if len(toolVersionParamsOutFileKeySet) == 0 and outFileKeyLength > 0:
+        myLogger.error_logger('output error')
+
     isInFileEqual = inFileKeyList.difference(toolVersionParamsInFileKeySet)
     if len(isInFileEqual) != 0:
         myLogger.error_logger('Input key and cmd key do not match')
